@@ -1,10 +1,9 @@
 import os, random, sys, time, csv, pickle, re, pkg_resources, mido
 os.environ['PYGAME_HIDE_SUPPORT_PROMPT']="hide"
-from tkinter import StringVar, DoubleVar, Tk, Label, Entry, Button, OptionMenu, \
-Checkbutton, Message, Menu, IntVar, Scale, HORIZONTAL, simpledialog, messagebox, Toplevel
-from tkinter.ttk import Progressbar, Separator, Combobox
+from tkinter import *
+from tkinter.ttk import *
 from tkinter import filedialog as fd 
-import tkinter.font as font
+from ttkthemes import ThemedTk
 from scipy.io import loadmat, savemat, whosmat
 from scipy.optimize import nnls
 from scipy.interpolate import interp1d
@@ -63,10 +62,10 @@ def run(display=True):
 	if display:
 		root.mainloop()
 	else:
-		print('Welcome to pyanthem v{}!'.format(pkg_resources.require("pyanthem")[0].version))
+		print('Welcome to pyanthem v{}!'.format(pkg_resources.require('pyanthem')[0].version))
 		return root
 
-class GUI(Tk):
+class GUI(ThemedTk):
 	def __init__(self,display=True):
 		'''
 		Initializes the GUI instance. display=True runs the Tk.__init__(self)
@@ -81,8 +80,8 @@ class GUI(Tk):
 			gdd.download_file_from_google_drive(file_id=sound_font,dest_path=\
 				os.path.join(os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts'),'font.sf2'),showsize=True)
 		if self.display:
-			Tk.__init__(self)
-			self.default_font=font.nametofont("TkDefaultFont")
+			ThemedTk.__init__(self)
+			self.set_theme('clearlooks')
 			self.initGUI()
 	
 	def quit(self,event=None):
@@ -221,7 +220,7 @@ class GUI(Tk):
 			if self.frameslider.get() > len(self.data['H_pp'].T): # This (usually) occurs when the user crops the dataset
 				self.frameslider.set(1)
 			self.frameslider['to']=int(len(self.data['H_pp'].T)-1)
-			self.imWH=self.Wax1.imshow((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@\
+			self.imWH=self.Wax1.imshow((self.data['W_pp']@np.diag(self.data['H_pp'][:,int(self.frameslider.get())])@\
 				self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3)\
 				.clip(min=0,max=255).astype('uint8'))
 			self.imW=self.Wax2.imshow((self.data['W_pp']@self.cmap[:,:-1]*255/np.max(self.data['W_pp'])).\
@@ -353,9 +352,9 @@ class GUI(Tk):
 
 	def refresh_slider(self,event):
 		'''
-		
+		Updates bottom left W plot with slider movement
 		'''
-		self.imWH.set_data((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
+		self.imWH.set_data((self.data['W_pp']@np.diag(self.data['H_pp'][:,int(self.frameslider.get())])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
 		self.canvas_W.draw()
 
 	def preview_notes(self):
@@ -383,7 +382,6 @@ class GUI(Tk):
 		track.append(mido.Message('note_off', note=self.keys[i], time=500))
 		mid.save(fn_midi)
 		cmd='fluidsynth -ni -F {} -r {} {} {} '.format(fn_wav,fs,fn_font,fn_midi)
-		print(cmd)
 		os.system(cmd)
 		music.load(fn_wav)
 		for i in range(len(self.keys)):
@@ -397,7 +395,13 @@ class GUI(Tk):
 			if i==0:
 				music.play(0)
 			time.sleep(.5-np.min(((time.time()-t),.5)))
-		time.sleep(1)
+		time.sleep(.5)
+		music.unload()
+		try:
+			os.remove(fn_midi)
+			os.remove(fn_wav)
+		except OSError as e:
+			print("Failed with:", e.strerror)
 		self.refresh_GUI()
 		
 	def write_audio(self):
@@ -596,25 +600,16 @@ class GUI(Tk):
 		self.threshold_entry=Entry(textvariable=self.threshold,width=7)
 		self.threshold_entry.grid(row=2, column=6, sticky='W')
 
+		# Styles
+		s = Style()
+		s.configure('my.TButton', font=('Helvetica', 14))
+
 		# Buttons
 		Button(text='Edit',command=self.edit_save_path,width=5).grid(row=6, column=2)
 		Button(text='Preview',width=11,command=self.preview_notes).grid(row=7, column=5,columnspan=1)
-		self.update_button=Button(text='Update',width=7,font='Helvetica 14 bold',command=self.process_H_W)
-		self.update_button.grid(row=9, column=1,columnspan=1)
 		
-		# Option Menus
-		self.octave_add_menu=OptionMenu(self,self.octave_add,*octave_add_opts.keys())
-		self.octave_add_menu.config(width=7)
-		self.octave_add_menu.grid(row=3, column=6, sticky='W')
-		self.scale_type_menu=OptionMenu(self,self.scale_type,*scale_keys.keys())
-		self.scale_type_menu.config(width=11,font=(self.default_font,(8)))
-		self.scale_type_menu.grid(row=4, column=6, sticky='W')
-		self.key_menu=OptionMenu(self,self.key,*key_opts.keys())
-		self.key_menu.config(width=7)
-		self.key_menu.grid(row=5, column=6, sticky='W')
-		self.sound_preset_menu=OptionMenu(self,self.sound_preset,*sound_presets.keys())
-		self.sound_preset_menu.config(width=7)
-		self.sound_preset_menu.grid(row=6, column=6, sticky='W')
+		self.update_button=Button(text='Update',width=7,command=self.process_H_W,style='my.TButton')
+		self.update_button.grid(row=9,column=1,columnspan=1)
 		
 		# Combo box
 		self.cmapchooser=Combobox(self,textvariable=self.cmapchoice,width=5)
@@ -624,6 +619,30 @@ class GUI(Tk):
 		self.cmapchooser.current()
 		self.cmap=[]
 
+		self.octave_add_menu=Combobox(self,textvariable=self.octave_add,width=7)
+		self.octave_add_menu['values']=tuple(octave_add_opts.keys())
+		self.octave_add_menu['state']='readonly'
+		self.octave_add_menu.grid(row=3, column=6, sticky='W')
+		self.octave_add_menu.current()
+
+		self.scale_type_menu=Combobox(self,textvariable=self.scale_type,width=11)
+		self.scale_type_menu['values']=tuple(scale_keys.keys())
+		self.scale_type_menu['state']='readonly'
+		self.scale_type_menu.grid(row=4, column=6, sticky='W')
+		self.scale_type_menu.current()
+
+		self.key_menu=Combobox(self,textvariable=self.key,width=7)
+		self.key_menu['values']=tuple(key_opts.keys())
+		self.key_menu['state']='readonly'
+		self.key_menu.grid(row=5, column=6, sticky='W')
+		self.key_menu.current()
+
+		self.sound_preset_menu=Combobox(self,textvariable=self.sound_preset,width=7)
+		self.sound_preset_menu['values']=tuple(sound_presets.keys())
+		self.sound_preset_menu['state']='readonly'
+		self.sound_preset_menu.grid(row=6, column=6, sticky='W')
+		self.sound_preset_menu.current()
+
 		# Checkbox
 		self.audio_analog=IntVar()
 		self.audio_analog.set(0)
