@@ -64,14 +64,13 @@ cmaps_opts=tuple(sorted(['viridis', 'plasma', 'inferno', 'magma', 'cividis',
 
 '''
 Google drive id for .sf2 files from https://sites.google.com/site/soundfonts4u/
-Currently a custom soundfont
 '''
 sound_font='17QuXRbApe0JTlYfBs7iSMCMu3xRWMHOV'
 sound_presets={
 'Piano':0,
-'Piano w/ Reverb':1,
-'Strings':2,
-'Rhodes':3
+'Strings':24,
+'E-Piano':10,
+'Pad':21
 }
 
 '''
